@@ -10,7 +10,7 @@ def search(
     query: Q = None,
     sources: List = [],
     highlights: Dict = {},
-    **extras
+    extras: Dict = {}
 ):
 
     """
